/**
 * This file Copyright (c) 2013-2018 Magnolia International
 * Ltd.  (http://www.magnolia-cms.com). All rights reserved.
 *
 *
 * This file is dual-licensed under both the Magnolia
 * Network Agreement and the GNU General Public License.
 * You may elect to use one or the other of these licenses.
 *
 * This file is distributed in the hope that it will be
 * useful, but AS-IS and WITHOUT ANY WARRANTY; without even the
 * implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE, TITLE, or NONINFRINGEMENT.
 * Redistribution, except as permitted by whichever of the GPL
 * or MNA you select, is prohibited.
 *
 * 1. For the GPL license (GPL), you can redistribute and/or
 * modify this file under the terms of the GNU General
 * Public License, Version 3, as published by the Free Software
 * Foundation.  You should have received a copy of the GNU
 * General Public License, Version 3 along with this program;
 * if not, write to the Free Software Foundation, Inc., 51
 * Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * 2. For the Magnolia Network Agreement (MNA), this file
 * and the accompanying materials are made available under the
 * terms of the MNA which accompanies this distribution, and
 * is available at http://www.magnolia-cms.com/mna.html
 *
 * Any modifications to this file must keep this entire header
 * intact.
 *
 */
package info.magnolia.ui.vaadin.editor.gwt.shared;

/**
 * Enumerates the platforms available for preview in page editor. Provides their display names and
 * attribute values to be used in the url.
 */
public enum PlatformType {

    DESKTOP("desktop", "Desktop"),
    TABLET_LANDSCAPE("tablet", "Tablet (landscape)", 1024, 768),
    TABLET_PORTRAIT("tablet", "Tablet (portrait)", 768, 1024),
    MOBILE_LANDSCAPE("smartphone", "Smartphone (landscape)", 667, 375),
    MOBILE_PORTRAIT("smartphone", "Smartphone (portrait)", 375, 667);

    private final String id;
    private final String displayName;
    private final int width;
    private final int height;

    PlatformType(String id, String displayName) {
        this(id, displayName, 0, 0);
    }

    PlatformType(String id, String displayName, int width, int height) {
        this.id = id;
        this.displayName = displayName;
        this.width = width;
        this.height = height;
    }

    @Override
    public String toString() {
        return displayName;
    }

    /**
     * This maps to the channel passed as parameter to the rendering engine: mgnlChannel.
     */
    public String getId() {
        return id;
    }

    public int getWidth() {
        return width;
    }

    public int getHeight() {
        return height;
    }
}
