/**
 * This file Copyright (c) 2016-2018 Magnolia International
 * Ltd.  (http://www.magnolia-cms.com). All rights reserved.
 *
 *
 * This file is dual-licensed under both the Magnolia
 * Network Agreement and the GNU General Public License.
 * You may elect to use one or the other of these licenses.
 *
 * This file is distributed in the hope that it will be
 * useful, but AS-IS and WITHOUT ANY WARRANTY; without even the
 * implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE, TITLE, or NONINFRINGEMENT.
 * Redistribution, except as permitted by whichever of the GPL
 * or MNA you select, is prohibited.
 *
 * 1. For the GPL license (GPL), you can redistribute and/or
 * modify this file under the terms of the GNU General
 * Public License, Version 3, as published by the Free Software
 * Foundation.  You should have received a copy of the GNU
 * General Public License, Version 3 along with this program;
 * if not, write to the Free Software Foundation, Inc., 51
 * Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * 2. For the Magnolia Network Agreement (MNA), this file
 * and the accompanying materials are made available under the
 * terms of the MNA which accompanies this distribution, and
 * is available at http://www.magnolia-cms.com/mna.html
 *
 * Any modifications to this file must keep this entire header
 * intact.
 *
 */
package info.magnolia.ui.vaadin.gwt.client.css;

import java.util.ArrayList;
import java.util.List;

import com.google.gwt.core.shared.GWT;

/**
 * Provides CSS for page editor edit bars.
 */
public class PageEditorCssProvider {

    public static final PageEditorCssProvider INSTANCE = GWT.create(PageEditorCssProvider.class);

    private static final String PAGE_EDITOR_CSS = "/VAADIN/themes/pages-app/page-editor.css";
    private static final String PAGE_EDITOR_LEGACY_CSS = "/VAADIN/themes/ui-app-pages/page-editor.css";

    public List<String> getCssLinks() {
        List<String> cssLinks = new ArrayList<>();
        cssLinks.add(isResurface() ? PAGE_EDITOR_CSS : PAGE_EDITOR_LEGACY_CSS);
        return cssLinks;
    }

    /**
     * Tries to determine whether we're on Magnolia6/Resurface.
     * In order to achieve that, one needs to get to the main document embedding the iframe containing the editable page.
     *
     * <cite>When a window is loaded in an &lt;iframe&gt;, &lt;object&gt;, or &lt;frame&gt;, its parent is the window with the element embedding the window.</cite>
     *
     * See https://developer.mozilla.org/en-US/docs/Web/API/Window/parent
     */
    private native boolean isResurface() /*-{
        return $wnd.parent.document.getElementsByClassName('resurfaceui').length > 0;

    }-*/;
}