/**
 * This file Copyright (c) 2016-2018 Magnolia International
 * Ltd.  (http://www.magnolia-cms.com). All rights reserved.
 *
 *
 * This file is dual-licensed under both the Magnolia
 * Network Agreement and the GNU General Public License.
 * You may elect to use one or the other of these licenses.
 *
 * This file is distributed in the hope that it will be
 * useful, but AS-IS and WITHOUT ANY WARRANTY; without even the
 * implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE, TITLE, or NONINFRINGEMENT.
 * Redistribution, except as permitted by whichever of the GPL
 * or MNA you select, is prohibited.
 *
 * 1. For the GPL license (GPL), you can redistribute and/or
 * modify this file under the terms of the GNU General
 * Public License, Version 3, as published by the Free Software
 * Foundation.  You should have received a copy of the GNU
 * General Public License, Version 3 along with this program;
 * if not, write to the Free Software Foundation, Inc., 51
 * Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * 2. For the Magnolia Network Agreement (MNA), this file
 * and the accompanying materials are made available under the
 * terms of the MNA which accompanies this distribution, and
 * is available at http://www.magnolia-cms.com/mna.html
 *
 * Any modifications to this file must keep this entire header
 * intact.
 *
 */
package info.magnolia.ui.vaadin.gwt.client.editor.event;

import info.magnolia.ui.vaadin.gwt.client.shared.ComponentElement;

import java.util.Map;

import com.google.gwt.event.shared.GwtEvent;

/**
 * Event used for triggering an action.
 */
public class ComponentActionEvent extends GwtEvent<ComponentActionEventHandler> {

    public static Type<ComponentActionEventHandler> TYPE = new Type<>();

    private final ComponentElement element;
    private final String actionName;
    private final Map<String, String> parameters;

    public ComponentActionEvent(String actionName, ComponentElement element, Map<String, String> parameters) {
        this.element = element;
        this.actionName = actionName;
        this.parameters = parameters;
    }

    @Override
    public Type<ComponentActionEventHandler> getAssociatedType() {
        return TYPE;
    }

    @Override
    protected void dispatch(ComponentActionEventHandler handler) {
        handler.onAction(this);
    }

    public String getActionName() {
        return actionName;
    }

    public Map<String, String> getParameters() {
        return parameters;
    }

    public ComponentElement getElement() {
        return element;
    }
}
