/**
 * This file Copyright (c) 2010-2018 Magnolia International
 * Ltd.  (http://www.magnolia-cms.com). All rights reserved.
 *
 *
 * This file is dual-licensed under both the Magnolia
 * Network Agreement and the GNU General Public License.
 * You may elect to use one or the other of these licenses.
 *
 * This file is distributed in the hope that it will be
 * useful, but AS-IS and WITHOUT ANY WARRANTY; without even the
 * implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE, TITLE, or NONINFRINGEMENT.
 * Redistribution, except as permitted by whichever of the GPL
 * or MNA you select, is prohibited.
 *
 * 1. For the GPL license (GPL), you can redistribute and/or
 * modify this file under the terms of the GNU General
 * Public License, Version 3, as published by the Free Software
 * Foundation.  You should have received a copy of the GNU
 * General Public License, Version 3 along with this program;
 * if not, write to the Free Software Foundation, Inc., 51
 * Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * 2. For the Magnolia Network Agreement (MNA), this file
 * and the accompanying materials are made available under the
 * terms of the MNA which accompanies this distribution, and
 * is available at http://www.magnolia-cms.com/mna.html
 *
 * Any modifications to this file must keep this entire header
 * intact.
 *
 */
package info.magnolia.ui.vaadin.gwt.client.widget.controlbar;

import info.magnolia.ui.vaadin.gwt.client.widget.controlbar.eventmanager.ControlBarEventHandler;
import info.magnolia.ui.vaadin.gwt.client.widget.controlbar.eventmanager.ControlBarEventManager;
import info.magnolia.ui.vaadin.gwt.client.widget.controlbar.listener.AreaListener;

import com.google.gwt.core.client.GWT;
import com.google.gwt.dom.client.Element;
import com.google.gwt.dom.client.NativeEvent;
import com.google.gwt.user.client.DOM;
import com.google.gwt.user.client.ui.FlowPanel;
import com.google.gwt.user.client.ui.Label;

/**
 * A Widget for adding components to area. Marks where a newly created component will be injected.
 * Is assembled by a {@link PlaceHolderBar} and an empty place holder area.
 */
public class ComponentPlaceHolder extends FlowPanel {

    private final static String PLACEHOLDER_CLASS_NAME = "mgnlPlaceholder";
    private final static String PLACEHOLDER_ELEMENT_BOX_CLASS_NAME = "mgnlPlaceholderBox";

    protected AreaListener listener;
    protected PlaceHolderBar placeHolderBar = new PlaceHolderBar();
    private boolean boxed;
    private boolean addable;

    public ComponentPlaceHolder() {
        setStyleName(SimpleBar.EDITOR_CLASS_NAME);
        addStyleName(PLACEHOLDER_CLASS_NAME);
    }

    protected void initLayout() {
        placeHolderBar.initLayout();
        add(placeHolderBar);

        if (addable) {
            placeHolderBar.createAddButton(listener);
        }

        if (boxed) {
            Element element = DOM.createDiv();
            element.addClassName(SimpleBar.EDITOR_CLASS_NAME);
            element.addClassName(PLACEHOLDER_ELEMENT_BOX_CLASS_NAME);
            getElement().appendChild(element);
        }
    }

    protected void addLabel(String label, int level) {
        placeHolderBar.addLabel(label, level);
    }

    @Override
    public void setVisible(boolean visible) {
        super.setVisible(visible);
        placeHolderBar.setVisible(visible);
    }

    @Override
    public void onAttach() {
        super.onAttach();
    }

    /**
     * A placeholder bar which resembles the {@link ComponentBar}.
     */
    private static class PlaceHolderBar extends AbstractBar {

        private ControlBarEventManager impl = GWT.create(ControlBarEventManager.class);

        public PlaceHolderBar() {
            addStyleName(COMPONENT_CLASS_NAME);
        }

        private void createAddButton(final AreaListener listener) {
            final Label add = new Label();
            add.setStyleName(ICON_CLASS_NAME);
            add.addStyleName(ADD_CLASS_NAME);
            impl.addClickOrTouchHandler(this, new ControlBarEventHandler() {
                @Override
                public void handle(NativeEvent event) {
                    listener.createNewComponent();
                }
            });
            addButton(add);
        }

    }

    /**
     * Builder for the component-placeholder widget and the belonging place-holder-bar widget.
     */
    public static class Builder {

        private AreaListener listener;
        private boolean boxed;
        private boolean addable;
        private String label;

        public Builder withListener(AreaListener listener) {
            this.listener = listener;
            return this;
        }

        public Builder withType(boolean isBox) {
            this.boxed = isBox;
            return this;
        }

        public Builder withAddButton(boolean isAdd) {
            this.addable = isAdd;
            return this;
        }

        public Builder withLabel(String label) {
            this.label = label;
            return this;
        }

        public ComponentPlaceHolder build() {
            ComponentPlaceHolder placeHolder = GWT.create(ComponentPlaceHolder.class);
            placeHolder.listener = listener;
            placeHolder.addable = addable;
            placeHolder.boxed = boxed;

            placeHolder.initLayout();
            placeHolder.addLabel(label, 0);
            placeHolder.setVisible(false);
            return placeHolder;
        }
    }
}
